@@ -1,6 +1,4 @@
 from django_pg.models.fields.array import ArrayField
 from django_pg.models.fields.composite import CompositeField
+from django_pg.models.fields.json import JSONField
 from django_pg.models.fields.uuid import UUIDField
-
-
-# __all__ = ['ArrayField', 'CompositeField', 'UUIDField']
